## NOTE: THIS FILE IS GENERATED BY EPSCRIPT! DO NOT MODITY
from eudplib import *
from eudplib.core.eudfunc import EUDTraceLog, EUDTracedFunc, EUDTracedTypedFunc, EUDTracedMethod, EUDTracedTypedMethod
from eudplib.epscript.helper import _RELIMP, _TYGV, _TYSV, _TYLV, _CGFW, _ARR, _VARR, _SRET, _SV, _ATTW, _ARRW, _ATTC, _ARRC, _L2V, _LSH, _ALL
# (Line 1) var a0 = 0;
a0 = _TYGV([None], lambda: [0])
# (Line 2) var a1 = 0;
a1 = _TYGV([None], lambda: [0])
# (Line 3) var a2 = 0;
a2 = _TYGV([None], lambda: [0])
# (Line 4) var a3 = 0;
a3 = _TYGV([None], lambda: [0])
# (Line 5) var a4 = 0;
a4 = _TYGV([None], lambda: [0])
# (Line 6) var a5 = 0;
a5 = _TYGV([None], lambda: [0])
# (Line 7) var a6 = 0;
a6 = _TYGV([None], lambda: [0])
# (Line 8) var a7 = 0;
a7 = _TYGV([None], lambda: [0])
# (Line 9) var a8 = 0;
a8 = _TYGV([None], lambda: [0])
# (Line 10) var a9 = 0;
a9 = _TYGV([None], lambda: [0])
# (Line 11) var a10 = 0;
a10 = _TYGV([None], lambda: [0])
# (Line 12) var a11 = 0;
a11 = _TYGV([None], lambda: [0])
# (Line 13) var a12 = 0;
a12 = _TYGV([None], lambda: [0])
# (Line 14) var a13 = 0;
a13 = _TYGV([None], lambda: [0])
# (Line 15) var a14 = 0;
a14 = _TYGV([None], lambda: [0])
# (Line 16) var a15 = 0;
a15 = _TYGV([None], lambda: [0])
# (Line 17) var a16 = 0;
a16 = _TYGV([None], lambda: [0])
# (Line 18) var a17 = 0;
a17 = _TYGV([None], lambda: [0])
# (Line 19) var a18 = 0;
a18 = _TYGV([None], lambda: [0])
# (Line 20) var a19 = 0;
a19 = _TYGV([None], lambda: [0])
# (Line 21) var a20 = 0;
a20 = _TYGV([None], lambda: [0])
# (Line 22) var a21 = 0;
a21 = _TYGV([None], lambda: [0])
# (Line 23) var a22 = 0;
a22 = _TYGV([None], lambda: [0])
# (Line 24) var a23 = 0;
a23 = _TYGV([None], lambda: [0])
# (Line 25) var a24 = 0;
a24 = _TYGV([None], lambda: [0])
# (Line 26) var a25 = 0;
a25 = _TYGV([None], lambda: [0])
# (Line 27) var a26 = 0;
a26 = _TYGV([None], lambda: [0])
# (Line 28) var a27 = 0;
a27 = _TYGV([None], lambda: [0])
# (Line 29) var a28 = 0;
a28 = _TYGV([None], lambda: [0])
# (Line 30) var a29 = 0;
a29 = _TYGV([None], lambda: [0])
# (Line 31) var a30 = 0;
a30 = _TYGV([None], lambda: [0])
# (Line 32) var a31 = 0;
a31 = _TYGV([None], lambda: [0])
# (Line 33) var a32 = 0;
a32 = _TYGV([None], lambda: [0])
# (Line 34) var a33 = 0;
a33 = _TYGV([None], lambda: [0])
# (Line 35) var a34 = 0;
a34 = _TYGV([None], lambda: [0])
# (Line 36) var a35 = 0;
a35 = _TYGV([None], lambda: [0])
# (Line 37) var a36 = 0;
a36 = _TYGV([None], lambda: [0])
# (Line 38) var a37 = 0;
a37 = _TYGV([None], lambda: [0])
# (Line 39) var a38 = 0;
a38 = _TYGV([None], lambda: [0])
# (Line 40) var a39 = 0;
a39 = _TYGV([None], lambda: [0])
# (Line 41) var a40 = 0;
a40 = _TYGV([None], lambda: [0])
# (Line 42) var a41 = 0;
a41 = _TYGV([None], lambda: [0])
# (Line 43) var a42 = 0;
a42 = _TYGV([None], lambda: [0])
# (Line 44) var a43 = 0;
a43 = _TYGV([None], lambda: [0])
# (Line 45) var a44 = 0;
a44 = _TYGV([None], lambda: [0])
# (Line 46) var a45 = 0;
a45 = _TYGV([None], lambda: [0])
# (Line 47) var a46 = 0;
a46 = _TYGV([None], lambda: [0])
# (Line 48) var a47 = 0;
a47 = _TYGV([None], lambda: [0])
# (Line 49) var a48 = 0;
a48 = _TYGV([None], lambda: [0])
# (Line 50) var a49 = 0;
a49 = _TYGV([None], lambda: [0])
# (Line 51) var a50 = 0;
a50 = _TYGV([None], lambda: [0])
# (Line 52) var a51 = 0;
a51 = _TYGV([None], lambda: [0])
# (Line 53) var a52 = 0;
a52 = _TYGV([None], lambda: [0])
# (Line 54) var a53 = 0;
a53 = _TYGV([None], lambda: [0])
# (Line 55) var a54 = 0;
a54 = _TYGV([None], lambda: [0])
# (Line 56) var a55 = 0;
a55 = _TYGV([None], lambda: [0])
# (Line 57) var a56 = 0;
a56 = _TYGV([None], lambda: [0])
# (Line 58) var a57 = 0;
a57 = _TYGV([None], lambda: [0])
# (Line 59) var a58 = 0;
a58 = _TYGV([None], lambda: [0])
# (Line 60) var a59 = 0;
a59 = _TYGV([None], lambda: [0])
# (Line 61) var a60 = 0;
a60 = _TYGV([None], lambda: [0])
# (Line 62) var a61 = 0;
a61 = _TYGV([None], lambda: [0])
# (Line 63) var a62 = 0;
a62 = _TYGV([None], lambda: [0])
# (Line 64) var a63 = 0;
a63 = _TYGV([None], lambda: [0])
# (Line 65) var a64 = 0;
a64 = _TYGV([None], lambda: [0])
# (Line 66) var a65 = 0;
a65 = _TYGV([None], lambda: [0])
# (Line 67) var a66 = 0;
a66 = _TYGV([None], lambda: [0])
# (Line 68) var a67 = 0;
a67 = _TYGV([None], lambda: [0])
# (Line 69) var a68 = 0;
a68 = _TYGV([None], lambda: [0])
# (Line 70) var a69 = 0;
a69 = _TYGV([None], lambda: [0])
# (Line 71) var a70 = 0;
a70 = _TYGV([None], lambda: [0])
# (Line 72) var a71 = 0;
a71 = _TYGV([None], lambda: [0])
# (Line 73) var a72 = 0;
a72 = _TYGV([None], lambda: [0])
# (Line 74) var a73 = 0;
a73 = _TYGV([None], lambda: [0])
# (Line 75) var a74 = 0;
a74 = _TYGV([None], lambda: [0])
# (Line 76) var a75 = 0;
a75 = _TYGV([None], lambda: [0])
# (Line 77) var a76 = 0;
a76 = _TYGV([None], lambda: [0])
# (Line 78) var a77 = 0;
a77 = _TYGV([None], lambda: [0])
# (Line 79) var a78 = 0;
a78 = _TYGV([None], lambda: [0])
# (Line 80) var a79 = 0;
a79 = _TYGV([None], lambda: [0])
# (Line 81) var a80 = 0;
a80 = _TYGV([None], lambda: [0])
# (Line 82) var a81 = 0;
a81 = _TYGV([None], lambda: [0])
# (Line 83) var a82 = 0;
a82 = _TYGV([None], lambda: [0])
# (Line 84) var a83 = 0;
a83 = _TYGV([None], lambda: [0])
# (Line 85) var a84 = 0;
a84 = _TYGV([None], lambda: [0])
# (Line 86) var a85 = 0;
a85 = _TYGV([None], lambda: [0])
# (Line 87) var a86 = 0;
a86 = _TYGV([None], lambda: [0])
# (Line 88) var a87 = 0;
a87 = _TYGV([None], lambda: [0])
# (Line 89) var a88 = 0;
a88 = _TYGV([None], lambda: [0])
# (Line 90) var a89 = 0;
a89 = _TYGV([None], lambda: [0])
# (Line 91) var a90 = 0;
a90 = _TYGV([None], lambda: [0])
# (Line 92) var a91 = 0;
a91 = _TYGV([None], lambda: [0])
# (Line 93) var a92 = 0;
a92 = _TYGV([None], lambda: [0])
# (Line 94) var a93 = 0;
a93 = _TYGV([None], lambda: [0])
# (Line 95) var a94 = 0;
a94 = _TYGV([None], lambda: [0])
# (Line 96) var a95 = 0;
a95 = _TYGV([None], lambda: [0])
# (Line 97) var a96 = 0;
a96 = _TYGV([None], lambda: [0])
# (Line 98) var a97 = 0;
a97 = _TYGV([None], lambda: [0])
# (Line 99) var a98 = 0;
a98 = _TYGV([None], lambda: [0])
# (Line 100) var a99 = 0;
a99 = _TYGV([None], lambda: [0])
# (Line 101) var a100 = 0;
a100 = _TYGV([None], lambda: [0])
# (Line 102) var a101 = 0;
a101 = _TYGV([None], lambda: [0])
# (Line 103) var a102 = 0;
a102 = _TYGV([None], lambda: [0])
# (Line 104) var a103 = 0;
a103 = _TYGV([None], lambda: [0])
# (Line 105) var a104 = 0;
a104 = _TYGV([None], lambda: [0])
# (Line 106) var a105 = 0;
a105 = _TYGV([None], lambda: [0])
# (Line 107) var a106 = 0;
a106 = _TYGV([None], lambda: [0])
# (Line 108) var a107 = 0;
a107 = _TYGV([None], lambda: [0])
# (Line 109) var a108 = 0;
a108 = _TYGV([None], lambda: [0])
# (Line 110) var a109 = 0;
a109 = _TYGV([None], lambda: [0])
# (Line 111) var a110 = 0;
a110 = _TYGV([None], lambda: [0])
# (Line 112) var a111 = 0;
a111 = _TYGV([None], lambda: [0])
# (Line 113) var a112 = 0;
a112 = _TYGV([None], lambda: [0])
# (Line 114) var a113 = 0;
a113 = _TYGV([None], lambda: [0])
# (Line 115) var a114 = 0;
a114 = _TYGV([None], lambda: [0])
# (Line 116) var a115 = 0;
a115 = _TYGV([None], lambda: [0])
# (Line 117) var a116 = 0;
a116 = _TYGV([None], lambda: [0])
# (Line 118) var a117 = 0;
a117 = _TYGV([None], lambda: [0])
# (Line 119) var a118 = 0;
a118 = _TYGV([None], lambda: [0])
# (Line 120) var a119 = 0;
a119 = _TYGV([None], lambda: [0])
# (Line 121) var a120 = 0;
a120 = _TYGV([None], lambda: [0])
# (Line 122) var a121 = 0;
a121 = _TYGV([None], lambda: [0])
# (Line 123) var a122 = 0;
a122 = _TYGV([None], lambda: [0])
# (Line 124) var a123 = 0;
a123 = _TYGV([None], lambda: [0])
# (Line 125) var a124 = 0;
a124 = _TYGV([None], lambda: [0])
# (Line 126) var a125 = 0;
a125 = _TYGV([None], lambda: [0])
# (Line 127) var a126 = 0;
a126 = _TYGV([None], lambda: [0])
# (Line 128) var a127 = 0;
a127 = _TYGV([None], lambda: [0])
# (Line 129) var a128 = 0;
a128 = _TYGV([None], lambda: [0])
# (Line 130) var a129 = 0;
a129 = _TYGV([None], lambda: [0])
# (Line 131) var a130 = 0;
a130 = _TYGV([None], lambda: [0])
# (Line 132) var a131 = 0;
a131 = _TYGV([None], lambda: [0])
# (Line 133) var a132 = 0;
a132 = _TYGV([None], lambda: [0])
# (Line 134) var a133 = 0;
a133 = _TYGV([None], lambda: [0])
# (Line 135) var a134 = 0;
a134 = _TYGV([None], lambda: [0])
# (Line 136) var a135 = 0;
a135 = _TYGV([None], lambda: [0])
# (Line 137) var a136 = 0;
a136 = _TYGV([None], lambda: [0])
# (Line 138) var a137 = 0;
a137 = _TYGV([None], lambda: [0])
# (Line 139) var a138 = 0;
a138 = _TYGV([None], lambda: [0])
# (Line 140) var a139 = 0;
a139 = _TYGV([None], lambda: [0])
# (Line 141) var a140 = 0;
a140 = _TYGV([None], lambda: [0])
# (Line 142) var a141 = 0;
a141 = _TYGV([None], lambda: [0])
# (Line 143) var a142 = 0;
a142 = _TYGV([None], lambda: [0])
# (Line 144) var a143 = 0;
a143 = _TYGV([None], lambda: [0])
# (Line 145) var a144 = 0;
a144 = _TYGV([None], lambda: [0])
# (Line 146) var a145 = 0;
a145 = _TYGV([None], lambda: [0])
# (Line 147) var a146 = 0;
a146 = _TYGV([None], lambda: [0])
# (Line 148) var a147 = 0;
a147 = _TYGV([None], lambda: [0])
# (Line 149) var a148 = 0;
a148 = _TYGV([None], lambda: [0])
# (Line 150) var a149 = 0;
a149 = _TYGV([None], lambda: [0])
# (Line 151) var a150 = 0;
a150 = _TYGV([None], lambda: [0])
# (Line 152) var a151 = 0;
a151 = _TYGV([None], lambda: [0])
# (Line 153) var a152 = 0;
a152 = _TYGV([None], lambda: [0])
# (Line 154) var a153 = 0;
a153 = _TYGV([None], lambda: [0])
# (Line 155) var a154 = 0;
a154 = _TYGV([None], lambda: [0])
# (Line 156) var a155 = 0;
a155 = _TYGV([None], lambda: [0])
# (Line 157) var a156 = 0;
a156 = _TYGV([None], lambda: [0])
# (Line 158) var a157 = 0;
a157 = _TYGV([None], lambda: [0])
# (Line 159) var a158 = 0;
a158 = _TYGV([None], lambda: [0])
# (Line 160) var a159 = 0;
a159 = _TYGV([None], lambda: [0])
# (Line 161) var a160 = 0;
a160 = _TYGV([None], lambda: [0])
# (Line 162) var a161 = 0;
a161 = _TYGV([None], lambda: [0])
# (Line 163) var a162 = 0;
a162 = _TYGV([None], lambda: [0])
# (Line 164) var a163 = 0;
a163 = _TYGV([None], lambda: [0])
# (Line 165) var a164 = 0;
a164 = _TYGV([None], lambda: [0])
# (Line 166) var a165 = 0;
a165 = _TYGV([None], lambda: [0])
# (Line 167) var a166 = 0;
a166 = _TYGV([None], lambda: [0])
# (Line 168) var a167 = 0;
a167 = _TYGV([None], lambda: [0])
# (Line 169) var a168 = 0;
a168 = _TYGV([None], lambda: [0])
# (Line 170) var a169 = 0;
a169 = _TYGV([None], lambda: [0])
# (Line 171) var a170 = 0;
a170 = _TYGV([None], lambda: [0])
# (Line 172) var a171 = 0;
a171 = _TYGV([None], lambda: [0])
# (Line 173) var a172 = 0;
a172 = _TYGV([None], lambda: [0])
# (Line 174) var a173 = 0;
a173 = _TYGV([None], lambda: [0])
# (Line 175) var a174 = 0;
a174 = _TYGV([None], lambda: [0])
# (Line 176) var a175 = 0;
a175 = _TYGV([None], lambda: [0])
# (Line 177) var a176 = 0;
a176 = _TYGV([None], lambda: [0])
# (Line 178) var a177 = 0;
a177 = _TYGV([None], lambda: [0])
# (Line 179) var a178 = 0;
a178 = _TYGV([None], lambda: [0])
# (Line 180) var a179 = 0;
a179 = _TYGV([None], lambda: [0])
# (Line 181) var a180 = 0;
a180 = _TYGV([None], lambda: [0])
# (Line 182) var a181 = 0;
a181 = _TYGV([None], lambda: [0])
# (Line 183) var a182 = 0;
a182 = _TYGV([None], lambda: [0])
# (Line 184) var a183 = 0;
a183 = _TYGV([None], lambda: [0])
# (Line 185) var a184 = 0;
a184 = _TYGV([None], lambda: [0])
# (Line 186) var a185 = 0;
a185 = _TYGV([None], lambda: [0])
# (Line 187) var a186 = 0;
a186 = _TYGV([None], lambda: [0])
# (Line 188) var a187 = 0;
a187 = _TYGV([None], lambda: [0])
# (Line 189) var a188 = 0;
a188 = _TYGV([None], lambda: [0])
# (Line 190) var a189 = 0;
a189 = _TYGV([None], lambda: [0])
# (Line 191) var a190 = 0;
a190 = _TYGV([None], lambda: [0])
# (Line 192) var a191 = 0;
a191 = _TYGV([None], lambda: [0])
# (Line 193) var a192 = 0;
a192 = _TYGV([None], lambda: [0])
# (Line 194) var a193 = 0;
a193 = _TYGV([None], lambda: [0])
# (Line 195) var a194 = 0;
a194 = _TYGV([None], lambda: [0])
# (Line 196) var a195 = 0;
a195 = _TYGV([None], lambda: [0])
# (Line 197) var a196 = 0;
a196 = _TYGV([None], lambda: [0])
# (Line 198) var a197 = 0;
a197 = _TYGV([None], lambda: [0])
# (Line 199) var a198 = 0;
a198 = _TYGV([None], lambda: [0])
# (Line 200) var a199 = 0;
a199 = _TYGV([None], lambda: [0])
# (Line 201) var a200 = 0;
a200 = _TYGV([None], lambda: [0])
# (Line 202) var a201 = 0;
a201 = _TYGV([None], lambda: [0])
# (Line 203) var a202 = 0;
a202 = _TYGV([None], lambda: [0])
# (Line 204) var a203 = 0;
a203 = _TYGV([None], lambda: [0])
# (Line 205) var a204 = 0;
a204 = _TYGV([None], lambda: [0])
# (Line 206) var a205 = 0;
a205 = _TYGV([None], lambda: [0])
# (Line 207) var a206 = 0;
a206 = _TYGV([None], lambda: [0])
# (Line 208) var a207 = 0;
a207 = _TYGV([None], lambda: [0])
# (Line 209) var a208 = 0;
a208 = _TYGV([None], lambda: [0])
# (Line 210) var a209 = 0;
a209 = _TYGV([None], lambda: [0])
# (Line 211) var a210 = 0;
a210 = _TYGV([None], lambda: [0])
# (Line 212) var a211 = 0;
a211 = _TYGV([None], lambda: [0])
# (Line 213) var a212 = 0;
a212 = _TYGV([None], lambda: [0])
# (Line 214) var a213 = 0;
a213 = _TYGV([None], lambda: [0])
# (Line 215) var a214 = 0;
a214 = _TYGV([None], lambda: [0])
# (Line 216) var a215 = 0;
a215 = _TYGV([None], lambda: [0])
# (Line 217) var a216 = 0;
a216 = _TYGV([None], lambda: [0])
# (Line 218) var a217 = 0;
a217 = _TYGV([None], lambda: [0])
# (Line 219) var a218 = 0;
a218 = _TYGV([None], lambda: [0])
# (Line 220) var a219 = 0;
a219 = _TYGV([None], lambda: [0])
# (Line 221) var a220 = 0;
a220 = _TYGV([None], lambda: [0])
# (Line 222) var a221 = 0;
a221 = _TYGV([None], lambda: [0])
# (Line 223) var a222 = 0;
a222 = _TYGV([None], lambda: [0])
# (Line 224) var a223 = 0;
a223 = _TYGV([None], lambda: [0])
# (Line 225) var a224 = 0;
a224 = _TYGV([None], lambda: [0])
# (Line 226) var a225 = 0;
a225 = _TYGV([None], lambda: [0])
# (Line 227) var a226 = 0;
a226 = _TYGV([None], lambda: [0])
# (Line 228) var a227 = 0;
a227 = _TYGV([None], lambda: [0])
# (Line 229) var a228 = 0;
a228 = _TYGV([None], lambda: [0])
# (Line 230) var a229 = 0;
a229 = _TYGV([None], lambda: [0])
# (Line 231) var a230 = 0;
a230 = _TYGV([None], lambda: [0])
# (Line 232) var a231 = 0;
a231 = _TYGV([None], lambda: [0])
# (Line 233) var a232 = 0;
a232 = _TYGV([None], lambda: [0])
# (Line 234) var a233 = 0;
a233 = _TYGV([None], lambda: [0])
# (Line 235) var a234 = 0;
a234 = _TYGV([None], lambda: [0])
# (Line 236) var a235 = 0;
a235 = _TYGV([None], lambda: [0])
# (Line 237) var a236 = 0;
a236 = _TYGV([None], lambda: [0])
# (Line 238) var a237 = 0;
a237 = _TYGV([None], lambda: [0])
# (Line 239) var a238 = 0;
a238 = _TYGV([None], lambda: [0])
# (Line 240) var a239 = 0;
a239 = _TYGV([None], lambda: [0])
# (Line 241) var a240 = 0;
a240 = _TYGV([None], lambda: [0])
# (Line 242) var a241 = 0;
a241 = _TYGV([None], lambda: [0])
# (Line 243) var a242 = 0;
a242 = _TYGV([None], lambda: [0])
# (Line 244) var a243 = 0;
a243 = _TYGV([None], lambda: [0])
# (Line 245) var a244 = 0;
a244 = _TYGV([None], lambda: [0])
# (Line 246) var a245 = 0;
a245 = _TYGV([None], lambda: [0])
# (Line 247) var a246 = 0;
a246 = _TYGV([None], lambda: [0])
# (Line 248) var a247 = 0;
a247 = _TYGV([None], lambda: [0])
# (Line 249) var a248 = 0;
a248 = _TYGV([None], lambda: [0])
# (Line 250) var a249 = 0;
a249 = _TYGV([None], lambda: [0])
# (Line 251) var a250 = 0;
a250 = _TYGV([None], lambda: [0])
# (Line 252) var a251 = 0;
a251 = _TYGV([None], lambda: [0])
# (Line 253) var a252 = 0;
a252 = _TYGV([None], lambda: [0])
# (Line 254) var a253 = 0;
a253 = _TYGV([None], lambda: [0])
# (Line 255) var a254 = 0;
a254 = _TYGV([None], lambda: [0])
# (Line 256) var a255 = 0;
a255 = _TYGV([None], lambda: [0])
# (Line 257) var a256 = 0;
a256 = _TYGV([None], lambda: [0])
# (Line 258) var a257 = 0;
a257 = _TYGV([None], lambda: [0])
# (Line 259) var a258 = 0;
a258 = _TYGV([None], lambda: [0])
# (Line 260) var a259 = 0;
a259 = _TYGV([None], lambda: [0])
# (Line 261) var a260 = 0;
a260 = _TYGV([None], lambda: [0])
# (Line 262) var a261 = 0;
a261 = _TYGV([None], lambda: [0])
# (Line 263) var a262 = 0;
a262 = _TYGV([None], lambda: [0])
# (Line 264) var a263 = 0;
a263 = _TYGV([None], lambda: [0])
# (Line 265) var a264 = 0;
a264 = _TYGV([None], lambda: [0])
# (Line 266) var a265 = 0;
a265 = _TYGV([None], lambda: [0])
# (Line 267) var a266 = 0;
a266 = _TYGV([None], lambda: [0])
# (Line 268) var a267 = 0;
a267 = _TYGV([None], lambda: [0])
# (Line 269) var a268 = 0;
a268 = _TYGV([None], lambda: [0])
# (Line 270) var a269 = 0;
a269 = _TYGV([None], lambda: [0])
# (Line 271) var a270 = 0;
a270 = _TYGV([None], lambda: [0])
# (Line 272) var a271 = 0;
a271 = _TYGV([None], lambda: [0])
# (Line 273) var a272 = 0;
a272 = _TYGV([None], lambda: [0])
# (Line 274) var a273 = 0;
a273 = _TYGV([None], lambda: [0])
# (Line 275) var a274 = 0;
a274 = _TYGV([None], lambda: [0])
# (Line 276) var a275 = 0;
a275 = _TYGV([None], lambda: [0])
# (Line 277) var a276 = 0;
a276 = _TYGV([None], lambda: [0])
# (Line 278) var a277 = 0;
a277 = _TYGV([None], lambda: [0])
# (Line 279) var a278 = 0;
a278 = _TYGV([None], lambda: [0])
# (Line 280) var a279 = 0;
a279 = _TYGV([None], lambda: [0])
# (Line 281) var a280 = 0;
a280 = _TYGV([None], lambda: [0])
# (Line 282) var a281 = 0;
a281 = _TYGV([None], lambda: [0])
# (Line 283) var a282 = 0;
a282 = _TYGV([None], lambda: [0])
# (Line 284) var a283 = 0;
a283 = _TYGV([None], lambda: [0])
# (Line 285) var a284 = 0;
a284 = _TYGV([None], lambda: [0])
# (Line 286) var a285 = 0;
a285 = _TYGV([None], lambda: [0])
# (Line 287) var a286 = 0;
a286 = _TYGV([None], lambda: [0])
# (Line 288) var a287 = 0;
a287 = _TYGV([None], lambda: [0])
# (Line 289) var a288 = 0;
a288 = _TYGV([None], lambda: [0])
# (Line 290) var a289 = 0;
a289 = _TYGV([None], lambda: [0])
# (Line 291) var a290 = 0;
a290 = _TYGV([None], lambda: [0])
# (Line 292) var a291 = 0;
a291 = _TYGV([None], lambda: [0])
# (Line 293) var a292 = 0;
a292 = _TYGV([None], lambda: [0])
# (Line 294) var a293 = 0;
a293 = _TYGV([None], lambda: [0])
# (Line 295) var a294 = 0;
a294 = _TYGV([None], lambda: [0])
# (Line 296) var a295 = 0;
a295 = _TYGV([None], lambda: [0])
# (Line 297) var a296 = 0;
a296 = _TYGV([None], lambda: [0])
# (Line 298) var a297 = 0;
a297 = _TYGV([None], lambda: [0])
# (Line 299) var a298 = 0;
a298 = _TYGV([None], lambda: [0])
# (Line 300) var a299 = 0;
a299 = _TYGV([None], lambda: [0])
# (Line 301) var a300 = 0;
a300 = _TYGV([None], lambda: [0])
# (Line 302) var a301 = 0;
a301 = _TYGV([None], lambda: [0])
# (Line 303) var a302 = 0;
a302 = _TYGV([None], lambda: [0])
# (Line 304) var a303 = 0;
a303 = _TYGV([None], lambda: [0])
# (Line 305) var a304 = 0;
a304 = _TYGV([None], lambda: [0])
# (Line 306) var a305 = 0;
a305 = _TYGV([None], lambda: [0])
# (Line 307) var a306 = 0;
a306 = _TYGV([None], lambda: [0])
# (Line 308) var a307 = 0;
a307 = _TYGV([None], lambda: [0])
# (Line 309) var a308 = 0;
a308 = _TYGV([None], lambda: [0])
# (Line 310) var a309 = 0;
a309 = _TYGV([None], lambda: [0])
# (Line 311) var a310 = 0;
a310 = _TYGV([None], lambda: [0])
# (Line 312) var a311 = 0;
a311 = _TYGV([None], lambda: [0])
# (Line 313) var a312 = 0;
a312 = _TYGV([None], lambda: [0])
# (Line 314) var a313 = 0;
a313 = _TYGV([None], lambda: [0])
# (Line 315) var a314 = 0;
a314 = _TYGV([None], lambda: [0])
# (Line 316) var a315 = 0;
a315 = _TYGV([None], lambda: [0])
# (Line 317) var a316 = 0;
a316 = _TYGV([None], lambda: [0])
# (Line 318) var a317 = 0;
a317 = _TYGV([None], lambda: [0])
# (Line 319) var a318 = 0;
a318 = _TYGV([None], lambda: [0])
# (Line 320) var a319 = 0;
a319 = _TYGV([None], lambda: [0])
# (Line 321) var a320 = 0;
a320 = _TYGV([None], lambda: [0])
# (Line 322) var a321 = 0;
a321 = _TYGV([None], lambda: [0])
# (Line 323) var a322 = 0;
a322 = _TYGV([None], lambda: [0])
# (Line 324) var a323 = 0;
a323 = _TYGV([None], lambda: [0])
# (Line 325) var a324 = 0;
a324 = _TYGV([None], lambda: [0])
# (Line 326) var a325 = 0;
a325 = _TYGV([None], lambda: [0])
# (Line 327) var a326 = 0;
a326 = _TYGV([None], lambda: [0])
# (Line 328) var a327 = 0;
a327 = _TYGV([None], lambda: [0])
# (Line 329) var a328 = 0;
a328 = _TYGV([None], lambda: [0])
# (Line 330) var a329 = 0;
a329 = _TYGV([None], lambda: [0])
# (Line 331) var a330 = 0;
a330 = _TYGV([None], lambda: [0])
# (Line 332) var a331 = 0;
a331 = _TYGV([None], lambda: [0])
# (Line 333) var a332 = 0;
a332 = _TYGV([None], lambda: [0])
# (Line 334) var a333 = 0;
a333 = _TYGV([None], lambda: [0])
# (Line 335) var a334 = 0;
a334 = _TYGV([None], lambda: [0])
# (Line 336) var a335 = 0;
a335 = _TYGV([None], lambda: [0])
# (Line 337) var a336 = 0;
a336 = _TYGV([None], lambda: [0])
# (Line 338) var a337 = 0;
a337 = _TYGV([None], lambda: [0])
# (Line 339) var a338 = 0;
a338 = _TYGV([None], lambda: [0])
# (Line 340) var a339 = 0;
a339 = _TYGV([None], lambda: [0])
# (Line 341) var a340 = 0;
a340 = _TYGV([None], lambda: [0])
# (Line 342) var a341 = 0;
a341 = _TYGV([None], lambda: [0])
# (Line 343) var a342 = 0;
a342 = _TYGV([None], lambda: [0])
# (Line 344) var a343 = 0;
a343 = _TYGV([None], lambda: [0])
# (Line 345) var a344 = 0;
a344 = _TYGV([None], lambda: [0])
# (Line 346) var a345 = 0;
a345 = _TYGV([None], lambda: [0])
# (Line 347) var a346 = 0;
a346 = _TYGV([None], lambda: [0])
# (Line 348) var a347 = 0;
a347 = _TYGV([None], lambda: [0])
# (Line 349) var a348 = 0;
a348 = _TYGV([None], lambda: [0])
# (Line 350) var a349 = 0;
a349 = _TYGV([None], lambda: [0])
# (Line 351) var a350 = 0;
a350 = _TYGV([None], lambda: [0])
# (Line 352) var a351 = 0;
a351 = _TYGV([None], lambda: [0])
# (Line 353) var a352 = 0;
a352 = _TYGV([None], lambda: [0])
# (Line 354) var a353 = 0;
a353 = _TYGV([None], lambda: [0])
# (Line 355) var a354 = 0;
a354 = _TYGV([None], lambda: [0])
# (Line 356) var a355 = 0;
a355 = _TYGV([None], lambda: [0])
# (Line 357) var a356 = 0;
a356 = _TYGV([None], lambda: [0])
# (Line 358) var a357 = 0;
a357 = _TYGV([None], lambda: [0])
# (Line 359) var a358 = 0;
a358 = _TYGV([None], lambda: [0])
# (Line 360) var a359 = 0;
a359 = _TYGV([None], lambda: [0])
# (Line 361) var a360 = 0;
a360 = _TYGV([None], lambda: [0])
# (Line 362) var a361 = 0;
a361 = _TYGV([None], lambda: [0])
# (Line 363) var a362 = 0;
a362 = _TYGV([None], lambda: [0])
# (Line 364) var a363 = 0;
a363 = _TYGV([None], lambda: [0])
# (Line 365) var a364 = 0;
a364 = _TYGV([None], lambda: [0])
# (Line 366) var a365 = 0;
a365 = _TYGV([None], lambda: [0])
# (Line 367) var a366 = 0;
a366 = _TYGV([None], lambda: [0])
# (Line 368) var a367 = 0;
a367 = _TYGV([None], lambda: [0])
# (Line 369) var a368 = 0;
a368 = _TYGV([None], lambda: [0])
# (Line 370) var a369 = 0;
a369 = _TYGV([None], lambda: [0])
# (Line 371) var a370 = 0;
a370 = _TYGV([None], lambda: [0])
# (Line 372) var a371 = 0;
a371 = _TYGV([None], lambda: [0])
# (Line 373) var a372 = 0;
a372 = _TYGV([None], lambda: [0])
# (Line 374) var a373 = 0;
a373 = _TYGV([None], lambda: [0])
# (Line 375) var a374 = 0;
a374 = _TYGV([None], lambda: [0])
# (Line 376) var a375 = 0;
a375 = _TYGV([None], lambda: [0])
# (Line 377) var a376 = 0;
a376 = _TYGV([None], lambda: [0])
# (Line 378) var a377 = 0;
a377 = _TYGV([None], lambda: [0])
# (Line 379) var a378 = 0;
a378 = _TYGV([None], lambda: [0])
# (Line 380) var a379 = 0;
a379 = _TYGV([None], lambda: [0])
# (Line 381) var a380 = 0;
a380 = _TYGV([None], lambda: [0])
# (Line 382) var a381 = 0;
a381 = _TYGV([None], lambda: [0])
# (Line 383) var a382 = 0;
a382 = _TYGV([None], lambda: [0])
# (Line 384) var a383 = 0;
a383 = _TYGV([None], lambda: [0])
# (Line 385) var a384 = 0;
a384 = _TYGV([None], lambda: [0])
# (Line 386) var a385 = 0;
a385 = _TYGV([None], lambda: [0])
# (Line 387) var a386 = 0;
a386 = _TYGV([None], lambda: [0])
# (Line 388) var a387 = 0;
a387 = _TYGV([None], lambda: [0])
# (Line 389) var a388 = 0;
a388 = _TYGV([None], lambda: [0])
# (Line 390) var a389 = 0;
a389 = _TYGV([None], lambda: [0])
# (Line 391) var a390 = 0;
a390 = _TYGV([None], lambda: [0])
# (Line 392) var a391 = 0;
a391 = _TYGV([None], lambda: [0])
# (Line 393) var a392 = 0;
a392 = _TYGV([None], lambda: [0])
# (Line 394) var a393 = 0;
a393 = _TYGV([None], lambda: [0])
# (Line 395) var a394 = 0;
a394 = _TYGV([None], lambda: [0])
# (Line 396) var a395 = 0;
a395 = _TYGV([None], lambda: [0])
# (Line 397) var a396 = 0;
a396 = _TYGV([None], lambda: [0])
# (Line 398) var a397 = 0;
a397 = _TYGV([None], lambda: [0])
# (Line 399) var a398 = 0;
a398 = _TYGV([None], lambda: [0])
# (Line 400) var a399 = 0;
a399 = _TYGV([None], lambda: [0])
# (Line 401) var a400 = 0;
a400 = _TYGV([None], lambda: [0])
# (Line 402) var a401 = 0;
a401 = _TYGV([None], lambda: [0])
# (Line 403) var a402 = 0;
a402 = _TYGV([None], lambda: [0])
# (Line 404) var a403 = 0;
a403 = _TYGV([None], lambda: [0])
# (Line 405) var a404 = 0;
a404 = _TYGV([None], lambda: [0])
# (Line 406) var a405 = 0;
a405 = _TYGV([None], lambda: [0])
# (Line 407) var a406 = 0;
a406 = _TYGV([None], lambda: [0])
# (Line 408) var a407 = 0;
a407 = _TYGV([None], lambda: [0])
# (Line 409) var a408 = 0;
a408 = _TYGV([None], lambda: [0])
# (Line 410) var a409 = 0;
a409 = _TYGV([None], lambda: [0])
# (Line 411) var a410 = 0;
a410 = _TYGV([None], lambda: [0])
# (Line 412) var a411 = 0;
a411 = _TYGV([None], lambda: [0])
# (Line 413) var a412 = 0;
a412 = _TYGV([None], lambda: [0])
# (Line 414) var a413 = 0;
a413 = _TYGV([None], lambda: [0])
# (Line 415) var a414 = 0;
a414 = _TYGV([None], lambda: [0])
# (Line 416) var a415 = 0;
a415 = _TYGV([None], lambda: [0])
# (Line 417) var a416 = 0;
a416 = _TYGV([None], lambda: [0])
# (Line 418) var a417 = 0;
a417 = _TYGV([None], lambda: [0])
# (Line 419) var a418 = 0;
a418 = _TYGV([None], lambda: [0])
# (Line 420) var a419 = 0;
a419 = _TYGV([None], lambda: [0])
# (Line 421) var a420 = 0;
a420 = _TYGV([None], lambda: [0])
# (Line 422) var a421 = 0;
a421 = _TYGV([None], lambda: [0])
# (Line 423) var a422 = 0;
a422 = _TYGV([None], lambda: [0])
# (Line 424) var a423 = 0;
a423 = _TYGV([None], lambda: [0])
# (Line 425) var a424 = 0;
a424 = _TYGV([None], lambda: [0])
# (Line 426) var a425 = 0;
a425 = _TYGV([None], lambda: [0])
# (Line 427) var a426 = 0;
a426 = _TYGV([None], lambda: [0])
# (Line 428) var a427 = 0;
a427 = _TYGV([None], lambda: [0])
# (Line 429) var a428 = 0;
a428 = _TYGV([None], lambda: [0])
# (Line 430) var a429 = 0;
a429 = _TYGV([None], lambda: [0])
# (Line 431) var a430 = 0;
a430 = _TYGV([None], lambda: [0])
# (Line 432) var a431 = 0;
a431 = _TYGV([None], lambda: [0])
# (Line 433) var a432 = 0;
a432 = _TYGV([None], lambda: [0])
# (Line 434) var a433 = 0;
a433 = _TYGV([None], lambda: [0])
# (Line 435) var a434 = 0;
a434 = _TYGV([None], lambda: [0])
# (Line 436) var a435 = 0;
a435 = _TYGV([None], lambda: [0])
# (Line 437) var a436 = 0;
a436 = _TYGV([None], lambda: [0])
# (Line 438) var a437 = 0;
a437 = _TYGV([None], lambda: [0])
# (Line 439) var a438 = 0;
a438 = _TYGV([None], lambda: [0])
# (Line 440) var a439 = 0;
a439 = _TYGV([None], lambda: [0])
# (Line 441) var a440 = 0;
a440 = _TYGV([None], lambda: [0])
# (Line 442) var a441 = 0;
a441 = _TYGV([None], lambda: [0])
# (Line 443) var a442 = 0;
a442 = _TYGV([None], lambda: [0])
# (Line 444) var a443 = 0;
a443 = _TYGV([None], lambda: [0])
# (Line 445) var a444 = 0;
a444 = _TYGV([None], lambda: [0])
# (Line 446) var a445 = 0;
a445 = _TYGV([None], lambda: [0])
# (Line 447) var a446 = 0;
a446 = _TYGV([None], lambda: [0])
# (Line 448) var a447 = 0;
a447 = _TYGV([None], lambda: [0])
# (Line 449) var a448 = 0;
a448 = _TYGV([None], lambda: [0])
# (Line 450) var a449 = 0;
a449 = _TYGV([None], lambda: [0])
# (Line 451) var a450 = 0;
a450 = _TYGV([None], lambda: [0])
# (Line 452) var a451 = 0;
a451 = _TYGV([None], lambda: [0])
# (Line 453) var a452 = 0;
a452 = _TYGV([None], lambda: [0])
# (Line 454) var a453 = 0;
a453 = _TYGV([None], lambda: [0])
# (Line 455) var a454 = 0;
a454 = _TYGV([None], lambda: [0])
# (Line 456) var a455 = 0;
a455 = _TYGV([None], lambda: [0])
# (Line 457) var a456 = 0;
a456 = _TYGV([None], lambda: [0])
# (Line 458) var a457 = 0;
a457 = _TYGV([None], lambda: [0])
# (Line 459) var a458 = 0;
a458 = _TYGV([None], lambda: [0])
# (Line 460) var a459 = 0;
a459 = _TYGV([None], lambda: [0])
# (Line 461) var a460 = 0;
a460 = _TYGV([None], lambda: [0])
# (Line 462) var a461 = 0;
a461 = _TYGV([None], lambda: [0])
# (Line 463) var a462 = 0;
a462 = _TYGV([None], lambda: [0])
# (Line 464) var a463 = 0;
a463 = _TYGV([None], lambda: [0])
# (Line 465) var a464 = 0;
a464 = _TYGV([None], lambda: [0])
# (Line 466) var a465 = 0;
a465 = _TYGV([None], lambda: [0])
# (Line 467) var a466 = 0;
a466 = _TYGV([None], lambda: [0])
# (Line 468) var a467 = 0;
a467 = _TYGV([None], lambda: [0])
# (Line 469) var a468 = 0;
a468 = _TYGV([None], lambda: [0])
# (Line 470) var a469 = 0;
a469 = _TYGV([None], lambda: [0])
# (Line 471) var a470 = 0;
a470 = _TYGV([None], lambda: [0])
# (Line 472) var a471 = 0;
a471 = _TYGV([None], lambda: [0])
# (Line 473) var a472 = 0;
a472 = _TYGV([None], lambda: [0])
# (Line 474) var a473 = 0;
a473 = _TYGV([None], lambda: [0])
# (Line 475) var a474 = 0;
a474 = _TYGV([None], lambda: [0])
# (Line 476) var a475 = 0;
a475 = _TYGV([None], lambda: [0])
# (Line 477) var a476 = 0;
a476 = _TYGV([None], lambda: [0])
# (Line 478) var a477 = 0;
a477 = _TYGV([None], lambda: [0])
# (Line 479) var a478 = 0;
a478 = _TYGV([None], lambda: [0])
# (Line 480) var a479 = 0;
a479 = _TYGV([None], lambda: [0])
# (Line 481) var a480 = 0;
a480 = _TYGV([None], lambda: [0])
# (Line 482) var a481 = 0;
a481 = _TYGV([None], lambda: [0])
# (Line 483) var a482 = 0;
a482 = _TYGV([None], lambda: [0])
# (Line 484) var a483 = 0;
a483 = _TYGV([None], lambda: [0])
# (Line 485) var a484 = 0;
a484 = _TYGV([None], lambda: [0])
# (Line 486) var a485 = 0;
a485 = _TYGV([None], lambda: [0])
# (Line 487) var a486 = 0;
a486 = _TYGV([None], lambda: [0])
# (Line 488) var a487 = 0;
a487 = _TYGV([None], lambda: [0])
# (Line 489) var a488 = 0;
a488 = _TYGV([None], lambda: [0])
# (Line 490) var a489 = 0;
a489 = _TYGV([None], lambda: [0])
# (Line 491) var a490 = 0;
a490 = _TYGV([None], lambda: [0])
# (Line 492) var a491 = 0;
a491 = _TYGV([None], lambda: [0])
# (Line 493) var a492 = 0;
a492 = _TYGV([None], lambda: [0])
# (Line 494) var a493 = 0;
a493 = _TYGV([None], lambda: [0])
# (Line 495) var a494 = 0;
a494 = _TYGV([None], lambda: [0])
# (Line 496) var a495 = 0;
a495 = _TYGV([None], lambda: [0])
# (Line 497) var a496 = 0;
a496 = _TYGV([None], lambda: [0])
# (Line 498) var a497 = 0;
a497 = _TYGV([None], lambda: [0])
# (Line 499) var a498 = 0;
a498 = _TYGV([None], lambda: [0])
# (Line 500) var a499 = 0;
a499 = _TYGV([None], lambda: [0])
# (Line 501) var x0 = dwread_epd(0);
x0 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 502) var x1 = dwread_epd(0);
x1 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 503) var x2 = dwread_epd(0);
x2 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 504) var x3 = dwread_epd(0);
x3 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 505) var x4 = dwread_epd(0);
x4 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 506) var x5 = dwread_epd(0);
x5 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 507) var x6 = dwread_epd(0);
x6 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 508) var x7 = dwread_epd(0);
x7 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 509) var x8 = dwread_epd(0);
x8 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 510) var x9 = dwread_epd(0);
x9 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 511) var x10 = dwread_epd(0);
x10 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 512) var x11 = dwread_epd(0);
x11 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 513) var x12 = dwread_epd(0);
x12 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 514) var x13 = dwread_epd(0);
x13 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 515) var x14 = dwread_epd(0);
x14 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 516) var x15 = dwread_epd(0);
x15 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 517) var x16 = dwread_epd(0);
x16 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 518) var x17 = dwread_epd(0);
x17 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 519) var x18 = dwread_epd(0);
x18 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 520) var x19 = dwread_epd(0);
x19 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 521) var x20 = dwread_epd(0);
x20 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 522) var x21 = dwread_epd(0);
x21 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 523) var x22 = dwread_epd(0);
x22 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 524) var x23 = dwread_epd(0);
x23 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 525) var x24 = dwread_epd(0);
x24 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 526) var x25 = dwread_epd(0);
x25 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 527) var x26 = dwread_epd(0);
x26 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 528) var x27 = dwread_epd(0);
x27 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 529) var x28 = dwread_epd(0);
x28 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 530) var x29 = dwread_epd(0);
x29 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 531) var x30 = dwread_epd(0);
x30 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 532) var x31 = dwread_epd(0);
x31 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 533) var x32 = dwread_epd(0);
x32 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 534) var x33 = dwread_epd(0);
x33 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 535) var x34 = dwread_epd(0);
x34 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 536) var x35 = dwread_epd(0);
x35 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 537) var x36 = dwread_epd(0);
x36 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 538) var x37 = dwread_epd(0);
x37 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 539) var x38 = dwread_epd(0);
x38 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 540) var x39 = dwread_epd(0);
x39 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 541) var x40 = dwread_epd(0);
x40 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 542) var x41 = dwread_epd(0);
x41 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 543) var x42 = dwread_epd(0);
x42 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 544) var x43 = dwread_epd(0);
x43 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 545) var x44 = dwread_epd(0);
x44 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 546) var x45 = dwread_epd(0);
x45 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 547) var x46 = dwread_epd(0);
x46 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 548) var x47 = dwread_epd(0);
x47 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 549) var x48 = dwread_epd(0);
x48 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 550) var x49 = dwread_epd(0);
x49 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 551) var x50 = dwread_epd(0);
x50 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 552) var x51 = dwread_epd(0);
x51 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 553) var x52 = dwread_epd(0);
x52 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 554) var x53 = dwread_epd(0);
x53 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 555) var x54 = dwread_epd(0);
x54 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 556) var x55 = dwread_epd(0);
x55 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 557) var x56 = dwread_epd(0);
x56 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 558) var x57 = dwread_epd(0);
x57 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 559) var x58 = dwread_epd(0);
x58 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 560) var x59 = dwread_epd(0);
x59 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 561) var x60 = dwread_epd(0);
x60 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 562) var x61 = dwread_epd(0);
x61 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 563) var x62 = dwread_epd(0);
x62 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 564) var x63 = dwread_epd(0);
x63 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 565) var x64 = dwread_epd(0);
x64 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 566) var x65 = dwread_epd(0);
x65 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 567) var x66 = dwread_epd(0);
x66 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 568) var x67 = dwread_epd(0);
x67 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 569) var x68 = dwread_epd(0);
x68 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 570) var x69 = dwread_epd(0);
x69 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 571) var x70 = dwread_epd(0);
x70 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 572) var x71 = dwread_epd(0);
x71 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 573) var x72 = dwread_epd(0);
x72 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 574) var x73 = dwread_epd(0);
x73 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 575) var x74 = dwread_epd(0);
x74 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 576) var x75 = dwread_epd(0);
x75 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 577) var x76 = dwread_epd(0);
x76 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 578) var x77 = dwread_epd(0);
x77 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 579) var x78 = dwread_epd(0);
x78 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 580) var x79 = dwread_epd(0);
x79 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 581) var x80 = dwread_epd(0);
x80 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 582) var x81 = dwread_epd(0);
x81 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 583) var x82 = dwread_epd(0);
x82 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 584) var x83 = dwread_epd(0);
x83 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 585) var x84 = dwread_epd(0);
x84 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 586) var x85 = dwread_epd(0);
x85 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 587) var x86 = dwread_epd(0);
x86 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 588) var x87 = dwread_epd(0);
x87 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 589) var x88 = dwread_epd(0);
x88 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 590) var x89 = dwread_epd(0);
x89 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 591) var x90 = dwread_epd(0);
x90 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 592) var x91 = dwread_epd(0);
x91 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 593) var x92 = dwread_epd(0);
x92 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 594) var x93 = dwread_epd(0);
x93 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 595) var x94 = dwread_epd(0);
x94 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 596) var x95 = dwread_epd(0);
x95 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 597) var x96 = dwread_epd(0);
x96 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 598) var x97 = dwread_epd(0);
x97 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 599) var x98 = dwread_epd(0);
x98 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 600) var x99 = dwread_epd(0);
x99 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 601) var x100 = dwread_epd(0);
x100 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 602) var x101 = dwread_epd(0);
x101 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 603) var x102 = dwread_epd(0);
x102 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 604) var x103 = dwread_epd(0);
x103 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 605) var x104 = dwread_epd(0);
x104 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 606) var x105 = dwread_epd(0);
x105 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 607) var x106 = dwread_epd(0);
x106 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 608) var x107 = dwread_epd(0);
x107 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 609) var x108 = dwread_epd(0);
x108 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 610) var x109 = dwread_epd(0);
x109 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 611) var x110 = dwread_epd(0);
x110 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 612) var x111 = dwread_epd(0);
x111 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 613) var x112 = dwread_epd(0);
x112 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 614) var x113 = dwread_epd(0);
x113 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 615) var x114 = dwread_epd(0);
x114 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 616) var x115 = dwread_epd(0);
x115 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 617) var x116 = dwread_epd(0);
x116 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 618) var x117 = dwread_epd(0);
x117 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 619) var x118 = dwread_epd(0);
x118 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 620) var x119 = dwread_epd(0);
x119 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 621) var x120 = dwread_epd(0);
x120 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 622) var x121 = dwread_epd(0);
x121 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 623) var x122 = dwread_epd(0);
x122 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 624) var x123 = dwread_epd(0);
x123 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 625) var x124 = dwread_epd(0);
x124 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 626) var x125 = dwread_epd(0);
x125 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 627) var x126 = dwread_epd(0);
x126 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 628) var x127 = dwread_epd(0);
x127 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 629) var x128 = dwread_epd(0);
x128 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 630) var x129 = dwread_epd(0);
x129 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 631) var x130 = dwread_epd(0);
x130 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 632) var x131 = dwread_epd(0);
x131 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 633) var x132 = dwread_epd(0);
x132 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 634) var x133 = dwread_epd(0);
x133 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 635) var x134 = dwread_epd(0);
x134 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 636) var x135 = dwread_epd(0);
x135 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 637) var x136 = dwread_epd(0);
x136 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 638) var x137 = dwread_epd(0);
x137 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 639) var x138 = dwread_epd(0);
x138 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 640) var x139 = dwread_epd(0);
x139 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 641) var x140 = dwread_epd(0);
x140 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 642) var x141 = dwread_epd(0);
x141 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 643) var x142 = dwread_epd(0);
x142 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 644) var x143 = dwread_epd(0);
x143 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 645) var x144 = dwread_epd(0);
x144 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 646) var x145 = dwread_epd(0);
x145 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 647) var x146 = dwread_epd(0);
x146 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 648) var x147 = dwread_epd(0);
x147 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 649) var x148 = dwread_epd(0);
x148 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 650) var x149 = dwread_epd(0);
x149 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 651) var x150 = dwread_epd(0);
x150 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 652) var x151 = dwread_epd(0);
x151 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 653) var x152 = dwread_epd(0);
x152 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 654) var x153 = dwread_epd(0);
x153 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 655) var x154 = dwread_epd(0);
x154 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 656) var x155 = dwread_epd(0);
x155 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 657) var x156 = dwread_epd(0);
x156 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 658) var x157 = dwread_epd(0);
x157 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 659) var x158 = dwread_epd(0);
x158 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 660) var x159 = dwread_epd(0);
x159 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 661) var x160 = dwread_epd(0);
x160 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 662) var x161 = dwread_epd(0);
x161 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 663) var x162 = dwread_epd(0);
x162 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 664) var x163 = dwread_epd(0);
x163 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 665) var x164 = dwread_epd(0);
x164 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 666) var x165 = dwread_epd(0);
x165 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 667) var x166 = dwread_epd(0);
x166 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 668) var x167 = dwread_epd(0);
x167 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 669) var x168 = dwread_epd(0);
x168 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 670) var x169 = dwread_epd(0);
x169 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 671) var x170 = dwread_epd(0);
x170 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 672) var x171 = dwread_epd(0);
x171 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 673) var x172 = dwread_epd(0);
x172 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 674) var x173 = dwread_epd(0);
x173 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 675) var x174 = dwread_epd(0);
x174 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 676) var x175 = dwread_epd(0);
x175 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 677) var x176 = dwread_epd(0);
x176 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 678) var x177 = dwread_epd(0);
x177 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 679) var x178 = dwread_epd(0);
x178 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 680) var x179 = dwread_epd(0);
x179 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 681) var x180 = dwread_epd(0);
x180 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 682) var x181 = dwread_epd(0);
x181 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 683) var x182 = dwread_epd(0);
x182 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 684) var x183 = dwread_epd(0);
x183 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 685) var x184 = dwread_epd(0);
x184 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 686) var x185 = dwread_epd(0);
x185 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 687) var x186 = dwread_epd(0);
x186 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 688) var x187 = dwread_epd(0);
x187 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 689) var x188 = dwread_epd(0);
x188 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 690) var x189 = dwread_epd(0);
x189 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 691) var x190 = dwread_epd(0);
x190 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 692) var x191 = dwread_epd(0);
x191 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 693) var x192 = dwread_epd(0);
x192 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 694) var x193 = dwread_epd(0);
x193 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 695) var x194 = dwread_epd(0);
x194 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 696) var x195 = dwread_epd(0);
x195 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 697) var x196 = dwread_epd(0);
x196 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 698) var x197 = dwread_epd(0);
x197 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 699) var x198 = dwread_epd(0);
x198 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 700) var x199 = dwread_epd(0);
x199 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 701) var x200 = dwread_epd(0);
x200 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 702) var x201 = dwread_epd(0);
x201 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 703) var x202 = dwread_epd(0);
x202 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 704) var x203 = dwread_epd(0);
x203 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 705) var x204 = dwread_epd(0);
x204 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 706) var x205 = dwread_epd(0);
x205 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 707) var x206 = dwread_epd(0);
x206 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 708) var x207 = dwread_epd(0);
x207 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 709) var x208 = dwread_epd(0);
x208 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 710) var x209 = dwread_epd(0);
x209 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 711) var x210 = dwread_epd(0);
x210 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 712) var x211 = dwread_epd(0);
x211 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 713) var x212 = dwread_epd(0);
x212 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 714) var x213 = dwread_epd(0);
x213 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 715) var x214 = dwread_epd(0);
x214 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 716) var x215 = dwread_epd(0);
x215 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 717) var x216 = dwread_epd(0);
x216 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 718) var x217 = dwread_epd(0);
x217 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 719) var x218 = dwread_epd(0);
x218 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 720) var x219 = dwread_epd(0);
x219 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 721) var x220 = dwread_epd(0);
x220 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 722) var x221 = dwread_epd(0);
x221 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 723) var x222 = dwread_epd(0);
x222 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 724) var x223 = dwread_epd(0);
x223 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 725) var x224 = dwread_epd(0);
x224 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 726) var x225 = dwread_epd(0);
x225 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 727) var x226 = dwread_epd(0);
x226 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 728) var x227 = dwread_epd(0);
x227 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 729) var x228 = dwread_epd(0);
x228 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 730) var x229 = dwread_epd(0);
x229 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 731) var x230 = dwread_epd(0);
x230 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 732) var x231 = dwread_epd(0);
x231 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 733) var x232 = dwread_epd(0);
x232 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 734) var x233 = dwread_epd(0);
x233 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 735) var x234 = dwread_epd(0);
x234 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 736) var x235 = dwread_epd(0);
x235 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 737) var x236 = dwread_epd(0);
x236 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 738) var x237 = dwread_epd(0);
x237 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 739) var x238 = dwread_epd(0);
x238 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 740) var x239 = dwread_epd(0);
x239 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 741) var x240 = dwread_epd(0);
x240 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 742) var x241 = dwread_epd(0);
x241 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 743) var x242 = dwread_epd(0);
x242 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 744) var x243 = dwread_epd(0);
x243 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 745) var x244 = dwread_epd(0);
x244 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 746) var x245 = dwread_epd(0);
x245 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 747) var x246 = dwread_epd(0);
x246 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 748) var x247 = dwread_epd(0);
x247 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 749) var x248 = dwread_epd(0);
x248 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 750) var x249 = dwread_epd(0);
x249 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 751) var x250 = dwread_epd(0);
x250 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 752) var x251 = dwread_epd(0);
x251 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 753) var x252 = dwread_epd(0);
x252 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 754) var x253 = dwread_epd(0);
x253 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 755) var x254 = dwread_epd(0);
x254 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 756) var x255 = dwread_epd(0);
x255 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 757) var x256 = dwread_epd(0);
x256 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 758) var x257 = dwread_epd(0);
x257 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 759) var x258 = dwread_epd(0);
x258 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 760) var x259 = dwread_epd(0);
x259 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 761) var x260 = dwread_epd(0);
x260 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 762) var x261 = dwread_epd(0);
x261 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 763) var x262 = dwread_epd(0);
x262 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 764) var x263 = dwread_epd(0);
x263 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 765) var x264 = dwread_epd(0);
x264 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 766) var x265 = dwread_epd(0);
x265 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 767) var x266 = dwread_epd(0);
x266 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 768) var x267 = dwread_epd(0);
x267 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 769) var x268 = dwread_epd(0);
x268 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 770) var x269 = dwread_epd(0);
x269 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 771) var x270 = dwread_epd(0);
x270 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 772) var x271 = dwread_epd(0);
x271 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 773) var x272 = dwread_epd(0);
x272 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 774) var x273 = dwread_epd(0);
x273 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 775) var x274 = dwread_epd(0);
x274 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 776) var x275 = dwread_epd(0);
x275 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 777) var x276 = dwread_epd(0);
x276 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 778) var x277 = dwread_epd(0);
x277 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 779) var x278 = dwread_epd(0);
x278 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 780) var x279 = dwread_epd(0);
x279 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 781) var x280 = dwread_epd(0);
x280 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 782) var x281 = dwread_epd(0);
x281 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 783) var x282 = dwread_epd(0);
x282 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 784) var x283 = dwread_epd(0);
x283 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 785) var x284 = dwread_epd(0);
x284 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 786) var x285 = dwread_epd(0);
x285 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 787) var x286 = dwread_epd(0);
x286 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 788) var x287 = dwread_epd(0);
x287 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 789) var x288 = dwread_epd(0);
x288 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 790) var x289 = dwread_epd(0);
x289 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 791) var x290 = dwread_epd(0);
x290 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 792) var x291 = dwread_epd(0);
x291 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 793) var x292 = dwread_epd(0);
x292 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 794) var x293 = dwread_epd(0);
x293 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 795) var x294 = dwread_epd(0);
x294 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 796) var x295 = dwread_epd(0);
x295 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 797) var x296 = dwread_epd(0);
x296 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 798) var x297 = dwread_epd(0);
x297 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 799) var x298 = dwread_epd(0);
x298 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 800) var x299 = dwread_epd(0);
x299 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 801) var x300 = dwread_epd(0);
x300 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 802) var x301 = dwread_epd(0);
x301 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 803) var x302 = dwread_epd(0);
x302 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 804) var x303 = dwread_epd(0);
x303 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 805) var x304 = dwread_epd(0);
x304 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 806) var x305 = dwread_epd(0);
x305 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 807) var x306 = dwread_epd(0);
x306 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 808) var x307 = dwread_epd(0);
x307 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 809) var x308 = dwread_epd(0);
x308 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 810) var x309 = dwread_epd(0);
x309 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 811) var x310 = dwread_epd(0);
x310 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 812) var x311 = dwread_epd(0);
x311 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 813) var x312 = dwread_epd(0);
x312 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 814) var x313 = dwread_epd(0);
x313 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 815) var x314 = dwread_epd(0);
x314 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 816) var x315 = dwread_epd(0);
x315 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 817) var x316 = dwread_epd(0);
x316 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 818) var x317 = dwread_epd(0);
x317 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 819) var x318 = dwread_epd(0);
x318 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 820) var x319 = dwread_epd(0);
x319 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 821) var x320 = dwread_epd(0);
x320 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 822) var x321 = dwread_epd(0);
x321 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 823) var x322 = dwread_epd(0);
x322 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 824) var x323 = dwread_epd(0);
x323 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 825) var x324 = dwread_epd(0);
x324 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 826) var x325 = dwread_epd(0);
x325 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 827) var x326 = dwread_epd(0);
x326 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 828) var x327 = dwread_epd(0);
x327 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 829) var x328 = dwread_epd(0);
x328 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 830) var x329 = dwread_epd(0);
x329 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 831) var x330 = dwread_epd(0);
x330 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 832) var x331 = dwread_epd(0);
x331 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 833) var x332 = dwread_epd(0);
x332 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 834) var x333 = dwread_epd(0);
x333 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 835) var x334 = dwread_epd(0);
x334 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 836) var x335 = dwread_epd(0);
x335 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 837) var x336 = dwread_epd(0);
x336 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 838) var x337 = dwread_epd(0);
x337 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 839) var x338 = dwread_epd(0);
x338 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 840) var x339 = dwread_epd(0);
x339 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 841) var x340 = dwread_epd(0);
x340 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 842) var x341 = dwread_epd(0);
x341 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 843) var x342 = dwread_epd(0);
x342 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 844) var x343 = dwread_epd(0);
x343 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 845) var x344 = dwread_epd(0);
x344 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 846) var x345 = dwread_epd(0);
x345 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 847) var x346 = dwread_epd(0);
x346 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 848) var x347 = dwread_epd(0);
x347 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 849) var x348 = dwread_epd(0);
x348 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 850) var x349 = dwread_epd(0);
x349 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 851) var x350 = dwread_epd(0);
x350 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 852) var x351 = dwread_epd(0);
x351 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 853) var x352 = dwread_epd(0);
x352 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 854) var x353 = dwread_epd(0);
x353 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 855) var x354 = dwread_epd(0);
x354 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 856) var x355 = dwread_epd(0);
x355 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 857) var x356 = dwread_epd(0);
x356 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 858) var x357 = dwread_epd(0);
x357 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 859) var x358 = dwread_epd(0);
x358 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 860) var x359 = dwread_epd(0);
x359 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 861) var x360 = dwread_epd(0);
x360 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 862) var x361 = dwread_epd(0);
x361 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 863) var x362 = dwread_epd(0);
x362 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 864) var x363 = dwread_epd(0);
x363 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 865) var x364 = dwread_epd(0);
x364 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 866) var x365 = dwread_epd(0);
x365 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 867) var x366 = dwread_epd(0);
x366 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 868) var x367 = dwread_epd(0);
x367 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 869) var x368 = dwread_epd(0);
x368 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 870) var x369 = dwread_epd(0);
x369 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 871) var x370 = dwread_epd(0);
x370 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 872) var x371 = dwread_epd(0);
x371 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 873) var x372 = dwread_epd(0);
x372 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 874) var x373 = dwread_epd(0);
x373 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 875) var x374 = dwread_epd(0);
x374 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 876) var x375 = dwread_epd(0);
x375 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 877) var x376 = dwread_epd(0);
x376 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 878) var x377 = dwread_epd(0);
x377 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 879) var x378 = dwread_epd(0);
x378 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 880) var x379 = dwread_epd(0);
x379 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 881) var x380 = dwread_epd(0);
x380 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 882) var x381 = dwread_epd(0);
x381 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 883) var x382 = dwread_epd(0);
x382 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 884) var x383 = dwread_epd(0);
x383 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 885) var x384 = dwread_epd(0);
x384 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 886) var x385 = dwread_epd(0);
x385 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 887) var x386 = dwread_epd(0);
x386 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 888) var x387 = dwread_epd(0);
x387 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 889) var x388 = dwread_epd(0);
x388 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 890) var x389 = dwread_epd(0);
x389 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 891) var x390 = dwread_epd(0);
x390 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 892) var x391 = dwread_epd(0);
x391 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 893) var x392 = dwread_epd(0);
x392 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 894) var x393 = dwread_epd(0);
x393 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 895) var x394 = dwread_epd(0);
x394 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 896) var x395 = dwread_epd(0);
x395 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 897) var x396 = dwread_epd(0);
x396 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 898) var x397 = dwread_epd(0);
x397 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 899) var x398 = dwread_epd(0);
x398 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 900) var x399 = dwread_epd(0);
x399 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 901) var x400 = dwread_epd(0);
x400 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 902) var x401 = dwread_epd(0);
x401 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 903) var x402 = dwread_epd(0);
x402 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 904) var x403 = dwread_epd(0);
x403 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 905) var x404 = dwread_epd(0);
x404 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 906) var x405 = dwread_epd(0);
x405 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 907) var x406 = dwread_epd(0);
x406 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 908) var x407 = dwread_epd(0);
x407 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 909) var x408 = dwread_epd(0);
x408 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 910) var x409 = dwread_epd(0);
x409 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 911) var x410 = dwread_epd(0);
x410 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 912) var x411 = dwread_epd(0);
x411 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 913) var x412 = dwread_epd(0);
x412 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 914) var x413 = dwread_epd(0);
x413 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 915) var x414 = dwread_epd(0);
x414 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 916) var x415 = dwread_epd(0);
x415 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 917) var x416 = dwread_epd(0);
x416 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 918) var x417 = dwread_epd(0);
x417 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 919) var x418 = dwread_epd(0);
x418 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 920) var x419 = dwread_epd(0);
x419 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 921) var x420 = dwread_epd(0);
x420 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 922) var x421 = dwread_epd(0);
x421 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 923) var x422 = dwread_epd(0);
x422 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 924) var x423 = dwread_epd(0);
x423 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 925) var x424 = dwread_epd(0);
x424 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 926) var x425 = dwread_epd(0);
x425 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 927) var x426 = dwread_epd(0);
x426 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 928) var x427 = dwread_epd(0);
x427 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 929) var x428 = dwread_epd(0);
x428 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 930) var x429 = dwread_epd(0);
x429 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 931) var x430 = dwread_epd(0);
x430 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 932) var x431 = dwread_epd(0);
x431 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 933) var x432 = dwread_epd(0);
x432 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 934) var x433 = dwread_epd(0);
x433 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 935) var x434 = dwread_epd(0);
x434 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 936) var x435 = dwread_epd(0);
x435 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 937) var x436 = dwread_epd(0);
x436 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 938) var x437 = dwread_epd(0);
x437 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 939) var x438 = dwread_epd(0);
x438 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 940) var x439 = dwread_epd(0);
x439 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 941) var x440 = dwread_epd(0);
x440 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 942) var x441 = dwread_epd(0);
x441 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 943) var x442 = dwread_epd(0);
x442 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 944) var x443 = dwread_epd(0);
x443 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 945) var x444 = dwread_epd(0);
x444 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 946) var x445 = dwread_epd(0);
x445 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 947) var x446 = dwread_epd(0);
x446 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 948) var x447 = dwread_epd(0);
x447 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 949) var x448 = dwread_epd(0);
x448 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 950) var x449 = dwread_epd(0);
x449 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 951) var x450 = dwread_epd(0);
x450 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 952) var x451 = dwread_epd(0);
x451 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 953) var x452 = dwread_epd(0);
x452 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 954) var x453 = dwread_epd(0);
x453 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 955) var x454 = dwread_epd(0);
x454 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 956) var x455 = dwread_epd(0);
x455 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 957) var x456 = dwread_epd(0);
x456 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 958) var x457 = dwread_epd(0);
x457 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 959) var x458 = dwread_epd(0);
x458 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 960) var x459 = dwread_epd(0);
x459 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 961) var x460 = dwread_epd(0);
x460 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 962) var x461 = dwread_epd(0);
x461 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 963) var x462 = dwread_epd(0);
x462 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 964) var x463 = dwread_epd(0);
x463 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 965) var x464 = dwread_epd(0);
x464 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 966) var x465 = dwread_epd(0);
x465 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 967) var x466 = dwread_epd(0);
x466 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 968) var x467 = dwread_epd(0);
x467 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 969) var x468 = dwread_epd(0);
x468 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 970) var x469 = dwread_epd(0);
x469 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 971) var x470 = dwread_epd(0);
x470 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 972) var x471 = dwread_epd(0);
x471 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 973) var x472 = dwread_epd(0);
x472 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 974) var x473 = dwread_epd(0);
x473 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 975) var x474 = dwread_epd(0);
x474 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 976) var x475 = dwread_epd(0);
x475 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 977) var x476 = dwread_epd(0);
x476 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 978) var x477 = dwread_epd(0);
x477 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 979) var x478 = dwread_epd(0);
x478 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 980) var x479 = dwread_epd(0);
x479 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 981) var x480 = dwread_epd(0);
x480 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 982) var x481 = dwread_epd(0);
x481 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 983) var x482 = dwread_epd(0);
x482 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 984) var x483 = dwread_epd(0);
x483 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 985) var x484 = dwread_epd(0);
x484 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 986) var x485 = dwread_epd(0);
x485 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 987) var x486 = dwread_epd(0);
x486 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 988) var x487 = dwread_epd(0);
x487 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 989) var x488 = dwread_epd(0);
x488 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 990) var x489 = dwread_epd(0);
x489 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 991) var x490 = dwread_epd(0);
x490 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 992) var x491 = dwread_epd(0);
x491 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 993) var x492 = dwread_epd(0);
x492 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 994) var x493 = dwread_epd(0);
x493 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 995) var x494 = dwread_epd(0);
x494 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 996) var x495 = dwread_epd(0);
x495 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 997) var x496 = dwread_epd(0);
x496 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 998) var x497 = dwread_epd(0);
x497 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 999) var x498 = dwread_epd(0);
x498 = _TYGV([None], lambda: [f_dwread_epd(0)])
# (Line 1000) var x499 = dwread_epd(0);
x499 = _TYGV([None], lambda: [f_dwread_epd(0)])



from helper import *


@EUDFunc
def f_mul(a, b):
    return a * b


@EUDFunc
def f_add(a, b):
    return a + b


@EUDFunc
def f_addmul(a, b):
    return a + b, a * b


@EUDTypedFunc([EUDFuncPtr(2, 1), None, None], [None])
def indirectcaller(f, a, b):
    return f(a, b)


@TestInstance
def test_typedfunc():
    a = indirectcaller(f_mul, 3, 6)
    test_equality("Simple indirect call", [a], [18])

    tptr = EUDTypedFuncPtr([EUDFuncPtr(2, 1), None, None], [None])(indirectcaller)
    b = tptr(f_add, 3, 6)
    test_equality("Typed function call via function pointer", [b], [9])


class TestStruct(EUDStruct):
    _fields_ = ["x"]

    def constructor(self, x):
        self.x = x


@EUDTypedFunc([TestStruct])
def retx(obj):
    return obj.x


@EUDTypedFunc([TestStruct, EUDFuncPtr(1, 1)])
def f1(obj, x):
    return x(obj)


@TestInstance
def test_typedfuncptr_to_funcptr():
    a = TestStruct(1)
    b = f1(a, retx)
    test_equality("Passing typedfuncptr to funcptr", b, 1)



## NOTE: THIS FILE IS GENERATED BY EPSCRIPT! DO NOT MODITY
from eudplib import *
from eudplib.core.eudfunc import EUDTraceLog, EUDTracedFunc, EUDTracedTypedFunc, EUDTracedMethod, EUDTracedTypedMethod
from eudplib.epscript.helper import _RELIMP, _TYGV, _TYSV, _TYLV, _CGFW, _ARR, _VARR, _SRET, _SV, _ATTW, _ARRW, _ATTC, _ARRC, _L2V, _LSH, _ALL
# (Line 1) import py_random;
import random
# (Line 2) import py_itertools;
import itertools
# (Line 3) import collections.deque;
from collections import deque
# (Line 4) const testArray = [1, 2, 3, 4];
testArray = _CGFW(lambda: [_ARR(FlattenList([1, 2, 3, 4]))], 1)[0]
# (Line 5) function test_write() {
@EUDFunc
def f_test_write():
    # (Line 6) const ret = py_list();
    ret = list()
    # (Line 8) const u32 = py_eval("lambda: random.randint(1, 0xFFFFFFFF)");
    u32 = eval("lambda: random.randint(1, 0xFFFFFFFF)")
    # (Line 9) const shift = py_eval("lambda: random.randint(0, 31)");
    shift = eval("lambda: random.randint(0, 31)")
    # (Line 11) const num = u32(), u32(), u32(), u32(), u32(), u32(),
    # (Line 12) shift(), shift(), u32(), u32(), u32();
    num = u32(), u32(), u32(), u32(), u32(), u32(), shift(), shift(), u32(), u32(), u32()
    # (Line 13) const numV = EUDArray(num);
    numV = EUDArray(num)
    # (Line 14) const numS = num, numV;
    numS = num, numV
    # (Line 15) setcurpl(getuserplayerid());
    f_setcurpl(f_getuserplayerid())
    # (Line 16) const dbg = StringBuffer(3000);
    dbg = StringBuffer(3000)
    # (Line 17) dbg.insert(0);
    dbg.insert(0)
    # (Line 18) foreach(vals : numS) {
    for vals in numS:
        # (Line 19) var expect = vals[0];
        expect = _TYLV([None], [vals[0]])
        # (Line 20) expect += vals[1];
        expect.__iadd__(vals[1])
        # (Line 21) expect -= vals[2];
        expect.__isub__(vals[2])
        # (Line 22) dbg.appendf("\n\x07{:x}\x02 *= {:x}", expect, vals[3],);
        dbg.appendf("\n\x07{:x}\x02 *= {:x}", expect, vals[3])
        # (Line 23) expect *= vals[3];
        expect.__imul__(vals[3])
        # (Line 24) var temp = expect;
        temp = _TYLV([None], [expect])
        # (Line 25) dbg.appendf(" -> \x07{:x}\x02 /= {:x}", expect, vals[4],);
        dbg.appendf(" -> \x07{:x}\x02 /= {:x}", expect, vals[4])
        # (Line 26) expect /= vals[4];
        expect.__ifloordiv__(vals[4])
        # (Line 27) temp += expect;
        temp.__iadd__(expect)
        # (Line 28) dbg.appendf(" -> \x07{}\x02 %= {:x}", expect, vals[5],);
        dbg.appendf(" -> \x07{}\x02 %= {:x}", expect, vals[5])
        # (Line 29) expect %= vals[5];
        expect.__imod__(vals[5])
        # (Line 30) temp += expect;
        temp.__iadd__(expect)
        # (Line 31) dbg.appendf(" -> \x07{}\x02 <<= {}", expect, vals[6],);
        dbg.appendf(" -> \x07{}\x02 <<= {}", expect, vals[6])
        # (Line 32) expect <<= vals[6];
        expect.__ilshift__(vals[6])
        # (Line 33) temp += expect;
        temp.__iadd__(expect)
        # (Line 34) dbg.appendf(" -> \x07{:x}\x02 >>= {}", expect, vals[7],);
        dbg.appendf(" -> \x07{:x}\x02 >>= {}", expect, vals[7])
        # (Line 35) expect >>= vals[7];
        expect.__irshift__(vals[7])
        # (Line 36) temp += expect;
        temp.__iadd__(expect)
        # (Line 39) dbg.appendf(" -> \x07{}\x02 &= {:x}", expect, vals[8]);
        dbg.appendf(" -> \x07{}\x02 &= {:x}", expect, vals[8])
        # (Line 40) expect &= vals[8];
        expect.__iand__(vals[8])
        # (Line 41) temp += expect;
        temp.__iadd__(expect)
        # (Line 42) dbg.appendf(" -> \x07{}\x02 |= {:x}", expect, vals[9]);
        dbg.appendf(" -> \x07{}\x02 |= {:x}", expect, vals[9])
        # (Line 43) expect |= vals[9];
        expect.__ior__(vals[9])
        # (Line 44) temp += expect;
        temp.__iadd__(expect)
        # (Line 45) dbg.appendf(" -> \x07{:x}", expect);
        dbg.appendf(" -> \x07{:x}", expect)
        # (Line 46) expect ^= vals[10];
        expect.__ixor__(vals[10])
        # (Line 47) temp += expect;
        temp.__iadd__(expect)
        # (Line 48) ret.append(temp);
        ret.append(temp)
        # (Line 49) }
        # (Line 50) const pvar, arr = PVariable(), EUDArray(8);

    pvar, arr = List2Assignable([PVariable(), EUDArray(8)])
    # (Line 51) var v1, v2 = pvar, arr;
    v1, v2 = _TYLV([None, None], [pvar, arr])
    # (Line 52) const pvarV, arrV = PVariable.cast(v1), EUDArray.cast(v2);
    pvarV, arrV = List2Assignable([PVariable.cast(v1), EUDArray.cast(v2)])
    # (Line 54) const index = py_eval("random.randint(0, 7)");
    index = eval("random.randint(0, 7)")
    # (Line 55) var indexV = index;
    indexV = _TYLV([None], [index])
    # (Line 57) foreach(arr, i, vals : py_eval("itertools.product(\
    # (Line 59) )")) {
    for arr_1, i, vals in eval("itertools.product(        (pvar, arr, pvarV, arrV), (index, indexV), (num, numV)    )"):
        # (Line 60) arr[i] = vals[0];
        _ARRW(arr_1, i) << (vals[0])
        # (Line 61) arr[i] += vals[1];
        _ARRW(arr_1, i).__iadd__(vals[1])
        # (Line 62) arr[i] -= vals[2];
        _ARRW(arr_1, i).__isub__(vals[2])
        # (Line 63) arr[i] *= vals[3];
        _ARRW(arr_1, i).__imul__(vals[3])
        # (Line 64) var temp = arr[i];
        temp = _TYLV([None], [arr_1[i]])
        # (Line 65) arr[i] /= vals[4];
        _ARRW(arr_1, i).__ifloordiv__(vals[4])
        # (Line 66) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 67) arr[i] %= vals[5];
        _ARRW(arr_1, i).__imod__(vals[5])
        # (Line 68) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 69) arr[i] <<= vals[6];
        _ARRW(arr_1, i).__ilshift__(vals[6])
        # (Line 70) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 71) arr[i] >>= vals[7];
        _ARRW(arr_1, i).__irshift__(vals[7])
        # (Line 72) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 75) arr[i] &= vals[8];
        _ARRW(arr_1, i).__iand__(vals[8])
        # (Line 76) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 77) arr[i] |= vals[9];
        _ARRW(arr_1, i).__ior__(vals[9])
        # (Line 78) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 79) arr[i] ^= vals[10];
        _ARRW(arr_1, i).__ixor__(vals[10])
        # (Line 80) temp += arr[i];
        temp.__iadd__(arr_1[i])
        # (Line 81) ret.append(temp);
        ret.append(temp)
        # (Line 82) }
        # (Line 83) dbg.Display();

    dbg.Display()
    # (Line 85) return List2Assignable(ret);
    EUDReturn(List2Assignable(ret))
    # (Line 86) }
    # (Line 87) function test_compare() {

@EUDFunc
def f_test_compare():
    # (Line 88) const ret = py_list();
    ret = list()
    # (Line 89) const num = py_eval("[random.randint(1, 0xFFFFFFFF) for _ in range(11)]");
    num = eval("[random.randint(1, 0xFFFFFFFF) for _ in range(11)]")
    # (Line 90) const numV = EUDArray(num);
    numV = EUDArray(num)
    # (Line 92) const pvar, arr = PVariable(), EUDArray(8);
    pvar, arr = List2Assignable([PVariable(), EUDArray(8)])
    # (Line 93) var v1, v2 = pvar, arr;
    v1, v2 = _TYLV([None, None], [pvar, arr])
    # (Line 94) const pvarV, arrV = PVariable.cast(v1), EUDArray.cast(v2);
    pvarV, arrV = List2Assignable([PVariable.cast(v1), EUDArray.cast(v2)])
    # (Line 96) const index = py_eval("random.randint(0, 7)");
    index = eval("random.randint(0, 7)")
    # (Line 97) var indexV = index;
    indexV = _TYLV([None], [index])
    # (Line 99) foreach(arr, i, vals : py_eval("itertools.product(\
    # (Line 101) )")) {
    for arr_1, i, vals in eval("itertools.product(        (pvar, arr, pvarV, arrV), (index, indexV), (num, numV)    )"):
        # (Line 102) var temp = 0;
        temp = _TYLV([None], [0])
        # (Line 103) arr[i] = vals[0];
        _ARRW(arr_1, i) << (vals[0])
        # (Line 104) if (arr[i] == vals[1]) temp += 1 << 1;
        if EUDIf()(_ARRC(arr_1, i) == vals[1]):
            temp.__iadd__(_LSH(1,1))
            # (Line 105) if (arr[i] != vals[2]) temp += 1 << 2;
        EUDEndIf()
        if EUDIf()(_ARRC(arr_1, i) == vals[2], neg=True):
            temp.__iadd__(_LSH(1,2))
            # (Line 106) if (arr[i] >= vals[3]) temp += 1 << 3;
        EUDEndIf()
        if EUDIf()(_ARRC(arr_1, i) >= vals[3]):
            temp.__iadd__(_LSH(1,3))
            # (Line 107) if (arr[i] <= vals[4]) temp += 1 << 4;
        EUDEndIf()
        if EUDIf()(_ARRC(arr_1, i) <= vals[4]):
            temp.__iadd__(_LSH(1,4))
            # (Line 108) if (arr[i] > vals[5]) temp += 1 << 5;
        EUDEndIf()
        if EUDIf()(_ARRC(arr_1, i) <= vals[5], neg=True):
            temp.__iadd__(_LSH(1,5))
            # (Line 109) if (arr[i] < vals[6]) temp += 1 << 6;
        EUDEndIf()
        if EUDIf()(_ARRC(arr_1, i) >= vals[6], neg=True):
            temp.__iadd__(_LSH(1,6))
            # (Line 110) ret.append(temp);
        EUDEndIf()
        ret.append(temp)
        # (Line 111) }
        # (Line 113) return List2Assignable(ret);

    EUDReturn(List2Assignable(ret))
    # (Line 114) }
    # (Line 115) const q8 = EUDQueue(8)();

q8 = _CGFW(lambda: [EUDQueue(8)()], 1)[0]
# (Line 116) function test_queue() {
@EUDFunc
def f_test_queue():
    # (Line 117) var ret = 0;
    ret = _TYLV([None], [0])
    # (Line 118) ret += q8.empty() ? 0b1 : 0;  // ret = 1
    ret.__iadd__(EUDTernary(q8.empty())(0b1)(0))
    # (Line 119) q8.append(1);
    q8.append(1)
    # (Line 120) q8.append(EUDVariable(2));
    q8.append(EUDVariable(2))
    # (Line 121) ret += 1 << q8.popleft();  // pop 1, ret = 3
    ret.__iadd__(_LSH(1,q8.popleft()))
    # (Line 122) q8.append(EUDVariable(3));
    q8.append(EUDVariable(3))
    # (Line 123) ret += q8.empty() ? 0x80000000 : 0;
    ret.__iadd__(EUDTernary(q8.empty())(0x80000000)(0))
    # (Line 124) ret += q8.popleft() == 2 ? 0b100 : 0;  // pop 2, ret = 7
    ret.__iadd__(EUDTernary(q8.popleft() == 2)(0b100)(0))
    # (Line 125) ret += q8.popleft() == 3 ? 0b1000 : 0;  // pop 3, ret = 15
    ret.__iadd__(EUDTernary(q8.popleft() == 3)(0b1000)(0))
    # (Line 126) ret += q8.empty() ? 0b10000 : 0;  // ret = 31
    ret.__iadd__(EUDTernary(q8.empty())(0b10000)(0))
    # (Line 127) return ret;
    EUDReturn(ret)
    # (Line 128) }
    # (Line 129) function test_queue_wraparound() {

@EUDFunc
def f_test_queue_wraparound():
    # (Line 130) const q3 = EUDQueue(3)();
    q3 = EUDQueue(3)()
    # (Line 131) const ret = EUDCreateVariables(6);
    ret = EUDCreateVariables(6)
    # (Line 132) var iter = 0;
    iter = _TYLV([None], [0])
    # (Line 134) foreach(v : q3) { ret[0] += v; iter++; }
    for v in q3:
        _ARRW(ret, 0).__iadd__(v)
        iter.__iadd__(1)
        # (Line 135) q3.append(1);

    q3.append(1)
    # (Line 136) q3.append(2);
    q3.append(2)
    # (Line 138) foreach(v : q3) { ret[1] += v; iter++; }
    for v in q3:
        _ARRW(ret, 1).__iadd__(v)
        iter.__iadd__(1)
        # (Line 139) q3.append(3);

    q3.append(3)
    # (Line 140) q3.append(4);
    q3.append(4)
    # (Line 142) foreach(v : q3) { ret[2] += v; iter++; }
    for v in q3:
        _ARRW(ret, 2).__iadd__(v)
        iter.__iadd__(1)
        # (Line 143) q3.append(5);

    q3.append(5)
    # (Line 145) foreach(v : q3) { ret[3] += v; iter++; }
    for v in q3:
        _ARRW(ret, 3).__iadd__(v)
        iter.__iadd__(1)
        # (Line 146) q3.popleft();

    q3.popleft()
    # (Line 148) foreach(v : q3) { ret[4] += v; iter++; }
    for v in q3:
        _ARRW(ret, 4).__iadd__(v)
        iter.__iadd__(1)
        # (Line 149) q3.append(6);

    q3.append(6)
    # (Line 150) q3.append(7);
    q3.append(7)
    # (Line 152) foreach(v : q3) {
    for v in q3:
        # (Line 153) if (v == 5) continue;
        if EUDIf()(v == 5):
            EUDContinue()
            # (Line 154) ret[5] += v;
        EUDEndIf()
        _ARRW(ret, 5).__iadd__(v)
        # (Line 155) EUDSetContinuePoint();
        EUDSetContinuePoint()
        # (Line 156) iter++;
        iter.__iadd__(1)
        # (Line 157) }
        # (Line 158) q3.append(8);

    q3.append(8)
    # (Line 159) q3.append(9);
    q3.append(9)
    # (Line 160) foreach(v : q3) {
    for v in q3:
        # (Line 161) if (v == 8) break;
        if EUDIf()(v == 8):
            EUDBreak()
            # (Line 162) ret[5] += v; iter++;
        EUDEndIf()
        _ARRW(ret, 5).__iadd__(v)
        iter.__iadd__(1)
        # (Line 163) }
        # (Line 164) ret.append(iter);

    ret.append(iter)
    # (Line 165) return List2Assignable(ret);
    EUDReturn(List2Assignable(ret))
    # (Line 166) }
    # (Line 167) const methods = py_eval('{\

# (Line 170) }');
methods = _CGFW(lambda: [eval('{    "append": "a",   "appendleft": "aL",    "pop":    "p",   "popleft":    "pL"}')], 1)[0]
# (Line 171) const DequeCases = py_eval('random.sample(sorted(methods), 27, counts=[9, 9, 9, 9])');
DequeCases = _CGFW(lambda: [eval('random.sample(sorted(methods), 27, counts=[9, 9, 9, 9])')], 1)[0]
# (Line 172) const DequeTest = py_eval("''.join(methods[name] for name in DequeCases)");
DequeTest = _CGFW(lambda: [eval("''.join(methods[name] for name in DequeCases)")], 1)[0]
# (Line 173) const dq = EUDDeque(7)();
dq = _CGFW(lambda: [EUDDeque(7)()], 1)[0]
# (Line 174) function test_deque() {
@EUDFunc
def f_test_deque():
    # (Line 175) const ret = py_list();
    ret = list()
    # (Line 176) var pushes = 1;
    pushes = _TYLV([None], [1])
    # (Line 178) const a = function () { dq.append(pushes); pushes++; };
    @EUDFunc
    def _lambda1():
        dq.append(pushes)
        pushes.__iadd__(1)

    a = _lambda1
    # (Line 179) const aL = function () { dq.appendleft(pushes); pushes++; };
    @EUDFunc
    def _lambda2():
        dq.appendleft(pushes)
        pushes.__iadd__(1)

    aL = _lambda2
    # (Line 180) const _p = function() { if (dq.empty()) return 0; else return dq.pop(); };
    @EUDFunc
    def _lambda3():
        if EUDIf()(dq.empty()):
            EUDReturn(0)
        if EUDElse()():
            EUDReturn(dq.pop())
        EUDEndIf()

    _p = _lambda3
    # (Line 181) const _pL = function() { if (dq.empty()) return 0; else return dq.popleft(); };
    @EUDFunc
    def _lambda4():
        if EUDIf()(dq.empty()):
            EUDReturn(0)
        if EUDElse()():
            EUDReturn(dq.popleft())
        EUDEndIf()

    _pL = _lambda4
    # (Line 182) const p = py_eval('lambda s=ret, f=_p: s.append(f())');
    p = eval('lambda s=ret, f=_p: s.append(f())')
    # (Line 183) const pL = py_eval('lambda s=ret, f=_pL: s.append(f())');
    pL = eval('lambda s=ret, f=_pL: s.append(f())')
    # (Line 184) const methodMap = py_eval('{\
    # (Line 187) }');
    methodMap = eval('{        "append":     a,    "pop":     p,        "appendleft": aL,   "popleft": pL,    }')
    # (Line 188) foreach(method : DequeCases) { methodMap[method](); }
    for method in DequeCases:
        methodMap[method]()
        # (Line 189) var sum = dq.length;

    sum = _TYLV([None], [dq.length])
    # (Line 190) foreach(element: dq) { sum += element; }
    for element in dq:
        sum.__iadd__(element)
        # (Line 191) ret.append(sum);

    ret.append(sum)
    # (Line 192) return List2Assignable(ret);
    EUDReturn(List2Assignable(ret))
    # (Line 193) }
    # (Line 194) function test_alias(): EUDArray {

@EUDTypedFunc([], [EUDArray])
def f_test_alias():
    # (Line 195) const a = EUDArray(10);
    a = EUDArray(10)
    # (Line 196) for(var i = 0 ; i < a.length ; i++) {
    i = _TYLV([None], [0])
    if EUDWhile()(i >= a.length, neg=True):
        def _t2():
            i.__iadd__(1)
        # (Line 197) a[i] = i;
        _ARRW(a, i) << (i)
        # (Line 198) }
        # (Line 199) return a;
        EUDSetContinuePoint()
        _t2()
    EUDEndWhile()
    EUDReturn(a)
    # (Line 200) }



# Copyright 2014 by trgk.
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

from collections.abc import Iterable
from typing import TypeAlias

from .. import core as c
from .. import utils as ut
from ..core.mapdata.playerinfo import PlayerInfo
from ..core.rawtrigger.constenc import _Player
from .triggerdef import Actions, Conditions, Trigger

_pinfos: list[PlayerInfo] = []
_pdbtable: dict[bytes, c.Db] = {}

Players: TypeAlias = _Player | int | Iterable[_Player | int | Iterable]


def init_ptrigger() -> None:
    """(Internal) Enable PTrigger. Internally called by eudplib"""
    global _pinfos
    if not _pinfos:
        _pinfos = [c.GetPlayerInfo(player) for player in range(8)]


def PTrigger(  # noqa: N802
    players: Players, conditions: Conditions = None, actions: Actions = None
) -> None:
    """Execute trigger by player basis

    :param players: Players the trigger should execute with. When Current
        Player specifies any of the players, trigger will execute.
    :param conditions: List of conditions. If all conditions are met, then
        actions will be executed.
    :param actions: List of actions.
    """

    init_ptrigger()

    players = ut.FlattenList(players)
    effp: list[bool] = [False] * 8

    # Trigger is never executed if it has no effplayers.
    if len(players) == 0:
        return

    # Check whose the player is executed to.
    for player in players:
        player = c.EncodePlayer(player)

        if 0 <= player <= 7:
            effp[player] = True

        elif 0x12 <= player <= 0x15:  # Force 1 ~ 4
            force_index = player - 0x12
            for p in range(8):
                if _pinfos[p].force == force_index:
                    effp[p] = True

        elif player == 0x11:  # All players
            for p in range(8):
                effp[p] = True
            break

    # Create player table!
    dbb = b"".join([b"\0\0\0\0" if eff is False else b"aaaa" for eff in effp])
    if dbb in _pdbtable:
        pdb = _pdbtable[dbb]

    else:
        pdb = c.Db(dbb)
        _pdbtable[dbb] = pdb

    # effplayer[p] is True  -> Memory(EPD(pdb) + p) == b'aaaa'
    # effplayer[p] is False -> Memory(EPD(pdb) + p) == b'\0\0\0\0'

    # Create triggers
    offset_curpl = 0x6509B0
    t1, t2, tc, t3 = c.Forward(), c.Forward(), c.Forward(), c.Forward()

    t1 << c.RawTrigger(
        nextptr=t3,
        conditions=c.Memory(offset_curpl, c.AtMost, 7),
        actions=[
            c.SetNextPtr(t1, t2),
            c.SetMemory(offset_curpl, c.Add, ut.EPD(pdb)),
        ],
    )

    t2 << c.RawTrigger(
        nextptr=t3,
        conditions=c.Deaths(13, c.Exactly, ut.b2i4(b"aaaa"), 0),  # CurrentPlayer
        actions=[
            c.SetNextPtr(t2, tc),
            c.SetMemory(offset_curpl, c.Subtract, ut.EPD(pdb)),
        ],
    )

    tc << c.NextTrigger()

    Trigger(conditions, actions)

    c.RawTrigger(
        actions=[
            c.SetNextPtr(t2, t3),
            c.SetMemory(offset_curpl, c.Add, ut.EPD(pdb)),
        ]
    )

    t3 << c.RawTrigger(
        actions=[
            c.SetNextPtr(t1, t3),
            c.SetMemory(offset_curpl, c.Subtract, ut.EPD(pdb)),
        ]
    )



## NOTE: THIS FILE IS GENERATED BY EPSCRIPT! DO NOT MODITY
from eudplib import *
from eudplib.core.eudfunc import EUDTraceLog, EUDTracedFunc, EUDTracedTypedFunc, EUDTracedMethod, EUDTracedTypedMethod
from eudplib.epscript.helper import _RELIMP, _TYGV, _TYSV, _TYLV, _CGFW, _ARR, _VARR, _SRET, _SV, _ATTW, _ARRW, _ATTC, _ARRC, _L2V, _LSH, _ALL
# (Line 1) const str = 1;
str = _CGFW(lambda: [1], 1)[0]
